@@ -1,4 +1,7 @@
 import autofit as af
+from autofit.exc import *
+from autoarray.exc import *
+from autogalaxy.exc import *
 
 
 class RayTracingException(af.exc.FitException):
@@ -21,13 +24,5 @@ class SettingsException(Exception):
     pass
 
 
-class AnalysisException(Exception):
-    pass
-
-
-class PreloadException(Exception):
-    pass
-
-
 class PointExtractionException(Exception):
     pass
