@@ -30,7 +30,7 @@ copyright = "2020, James Nightingale, Richard Hayes"
 author = "James Nightingale, Richard Hayes"
 
 # The full version, including alpha/beta/rc tags
-release = "1.15.3"
+release = "2021.10.14.1"
 master_doc = "index"
 
 
