@@ -7,9 +7,7 @@ rm -rf $p/build
 
 set -e
 
-VERSION=$1
-
-git flow release start $VERSION
+export VERSION=$1
 
 cat $PACKAGE_NAME/__init__.py | grep -v __version__ > temp
 
@@ -23,18 +21,11 @@ set +e
 git commit -m "Incremented version number"
 set -e
 
-# pytest $p
-
 python3 setup.py sdist bdist_wheel
 twine upload dist/* --skip-existing --username $PYPI_USERNAME --password $PYPI_PASSWORD
 
-git flow release finish $VERSION
 
-git checkout master
-git merge development
-git push
-git checkout development
-git push
+git push --tags
 
 rm -rf $p/dist
 rm -rf $p/build
