@@ -32,13 +32,8 @@ class TestLabel:
 
     def test_escaped(self, label_config):
         assert label_config["label"]["gamma"] == r"\gamma"
-        assert label_config["label"]["contribution_factor"] == r"\omega0"
-
-    # def test_subscript(self, label_config):
-    #     assert label_config["subscript"].family(al.lp.EllLightProfile) == "l"
-    #
-    # def test_inheritance(self, label_config):
-    #     assert label_config["subscript"].family(al.lp.EllGaussian) == "l"
+        print(label_config["label"]["contribution_factor"])
+        assert label_config["label"]["contribution_factor"] == r"\omega_{\rm 0}"
 
     def test_exception(self, label_config):
         with pytest.raises(KeyError):
